@@ -24,7 +24,7 @@ func evaluate(obj any, s string) (*structpb.Value, error) {
 	for _, key := range strings.Split(s, ".") {
 		res, err := DigObject(obj, key)
 		if err != nil {
-			return nil, fmt.Errorf("%s: %s", s, err)
+			return nil, fmt.Errorf("%s: %w", s, err)
 		}
 		obj = res
 	}
