@@ -9,7 +9,7 @@ type InterpolationContext struct {
 	Env         map[string]string          `json:"env"`
 	ExportFile  string                     `json:"export_file"`
 	Inputs      map[string]*structpb.Value `json:"inputs"`
-	Job         map[string]string          `json:"job"`
+	Job         map[string]*structpb.Value `json:"job"`
 	OutputFile  string                     `json:"output_file"`
 	StepDir     string                     `json:"step_dir"`
 	StepResults map[string]*StepResultView `json:"steps"`
