@@ -14,7 +14,7 @@ import (
 func TestGlobalContext_Log(t *testing.T) {
 	t.Run("no error", func(t *testing.T) {
 		output := &strings.Builder{}
-		globalCtx := runner.NewGlobalContext(".", map[string]string{}, bldr.Env().Build(), output, output)
+		globalCtx := runner.NewGlobalContext(".", bldr.JobVars(t).Build(), bldr.Env().Build(), output, output)
 
 		err := globalCtx.Logf("Hello %s!", "World")
 		require.NoError(t, err)
@@ -23,7 +23,7 @@ func TestGlobalContext_Log(t *testing.T) {
 
 	t.Run("when errors", func(t *testing.T) {
 		output := &ErrWriter{err: errors.New("simulated.error")}
-		globalCtx := runner.NewGlobalContext(".", map[string]string{}, bldr.Env().Build(), output, output)
+		globalCtx := runner.NewGlobalContext(".", bldr.JobVars(t).Build(), bldr.Env().Build(), output, output)
 
 		err := globalCtx.Logf("log message")
 		require.Error(t, err)
