@@ -9,7 +9,7 @@ import (
 var LogLevelEnvName = "CI_STEPS_LOG_LEVEL"
 
 // GlobalEnvironment sets environment variables that are always available for any step
-func GlobalEnvironment(parent *Environment, jobVars map[string]string) (*Environment, error) {
+func GlobalEnvironment(parent *Environment, jobVars JobVariables) (*Environment, error) {
 	globalEnv := make(map[string]string)
 
 	level, err := logLevel(parent, jobVars)
@@ -21,8 +21,8 @@ func GlobalEnvironment(parent *Environment, jobVars map[string]string) (*Environ
 	return parent.AddLexicalScope(NewEnvironment(globalEnv).Values()), nil
 }
 
-func logLevel(parent *Environment, jobVars map[string]string) (map[string]string, error) {
-	level := strings.ToLower(strings.TrimSpace(jobVars[LogLevelEnvName]))
+func logLevel(parent *Environment, jobVars JobVariables) (map[string]string, error) {
+	level := strings.ToLower(strings.TrimSpace(jobVars.StringValueOf(LogLevelEnvName)))
 
 	if level == "" {
 		level = strings.ToLower(strings.TrimSpace(parent.ValueOf(LogLevelEnvName)))
