@@ -26,7 +26,7 @@ func (bldr *InterpolationCtxBuilder) Build() *expression.InterpolationContext {
 		Env:         bldr.env,
 		ExportFile:  "export_file",
 		Inputs:      map[string]*structpb.Value{},
-		Job:         map[string]string{},
+		Job:         map[string]*structpb.Value{},
 		OutputFile:  "output_file",
 		StepDir:     "step.dir",
 		StepResults: map[string]*expression.StepResultView{},
